@@ -467,10 +467,41 @@ class Book(object):
     fullname : str or path-like object, default None
         Full path or name (incl. xlsx, xlsm etc.) of existing workbook or name of an unsaved workbook. Without a full
         path, it looks for the file in the current working directory.
+    update_links : bool, default None
+        If this argument is omitted, the user is prompted to specify how links will be updated
+    read_only : bool, default False
+        True to open workbook in read-only mode
+    format : str
+        If opening a text file, this specifies the delimiter character
+    password : str
+        Password to open a protected workbook
+    write_res_password : str
+        Password to write to a write-reserved workbook
+    ignore_read_only_recommended : bool, default False
+        Set to ``True`` to mute the read-only recommended message
+    origin : int
+        For text files only. Specifies where it originated. Use XlPlatform constants.
+    delimiter : str
+        If format argument is 6, this specifies the delimiter.
+    editable : bool, default False
+        This option is only for legacy Microsoft Excel 4.0 addins.
+    notify : bool, default False
+        Notify the user when a file becomes available If the file cannot be opened in read/write mode.
+    converter : int
+        The index of the first file converter to try when opening the file.
+    add_to_mru : bool, default False
+        Add this workbook to the list of recently added workbooks.
+    local : bool, default False
+        If ``True``, saves files against the language of Excel, otherwise against the language of VBA.
+        Not supported on macOS.
+    corrupt_load : int, default xlNormalLoad
+        Can be one of xlNormalLoad, xlRepairFile or xlExtractData. Not supported on macOS.
 
     """
 
-    def __init__(self, fullname=None, impl=None):
+    def __init__(self, fullname=None, update_links=None, read_only=None, format=None, password=None, write_res_password=None,
+                 ignore_read_only_recommended=None, origin=None, delimiter=None, editable=None, notify=None, converter=None,
+                 add_to_mru=None, local=None, corrupt_load=None, impl=None):
         if not impl:
             if fullname:
                 fullname = utils.fspath(fullname)
@@ -483,10 +514,12 @@ class Book(object):
                             candidates.append((app, wb))
 
                 app = apps.active
-                if len(candidates) == 0:                    
+                if len(candidates) == 0:
                     if not app:
                         app = App(add_book=False)
-                    impl = app.books.open(fullname).impl                                     
+                    impl = app.books.open(fullname, update_links, read_only, format, password, write_res_password,
+                                          ignore_read_only_recommended, origin, delimiter, editable, notify, converter,
+                                          add_to_mru, local, corrupt_load).impl
                 elif len(candidates) > 1:
                     raise Exception("Workbook '%s' is open in more than one Excel instance." % fullname)
                 else:
@@ -2752,7 +2785,9 @@ class Books(Collection):
         """
         return Book(impl=self.impl.add())
 
-    def open(self, fullname):
+    def open(self, fullname, update_links=None, read_only=None, format=None, password=None, write_res_password=None,
+             ignore_read_only_recommended=None, origin=None, delimiter=None, editable=None, notify=None, converter=None,
+             add_to_mru=None, local=None, corrupt_load=None):
         """
         Opens a Book if it is not open yet and returns it. If it is already open, it doesn't raise an exception but
         simply returns the Book object.
@@ -2763,6 +2798,9 @@ class Books(Collection):
             filename or fully qualified filename, e.g. ``r'C:\\path\\to\\file.xlsx'`` or ``'file.xlsm'``. Without a full
             path, it looks for the file in the current working directory.
 
+        Other Parameters
+            see: :meth:`xlwings.Book()`
+
         Returns
         -------
         Book : Book that has been opened.
@@ -2788,7 +2826,9 @@ class Books(Collection):
                     "Cannot open two workbooks named '%s', even if they are saved in different locations." % name
                 )
         except KeyError:
-            impl = self.impl.open(fullname)
+            impl = self.impl.open(fullname, update_links, read_only, format, password, write_res_password,
+                                  ignore_read_only_recommended, origin, delimiter, editable, notify, converter,
+                                  add_to_mru, local, corrupt_load)
         return Book(impl=impl)
 
 
